#
# spec file for package PlotDigitizer
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           PlotDigitizer
Version:        2.6.8
Release:        3.3
Summary:        Ditigize scanned plots of functional data
License:        LGPL-2.1 and GPL-2.0
Group:          Productivity/Scientific/Other
Url:            http://plotdigitizer.sourceforge.net
Source0:        http://downloads.sourceforge.net/plotdigitizer/%{name}_%{version}_Source.zip
Source1:        BareBonesBrowserLaunch.java
Source2:        PlotDigitizer.desktop
# MRJAdapter from PlotDigitizer 2.5.1 source archive
Source3:        MRJAdapter_1.0.8_Src.zip
Source4:        PlotDigitizer.appdata.xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ant
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  sed
BuildRequires:  unzip
BuildRequires:  update-alternatives
Requires:       autotrace
Requires:       java >= 1.6.0
Requires:       jpackage-utils
BuildArch:      noarch

%description

Plot Digitizer is a Java program used to digitize scanned plots of functional data. Often data is found presented in reports and references as functional X-Y type scatter or line plots. In order to use this data, it must somehow be digitized. This program will allow you to take a scanned image of a plot (in GIF, JPEG, or PNG format) and quickly digitize values off the plot just by clicking the mouse on each data point. The numbers can then be saved to a text file and used where ever you need them. Plot Digitizer works with both linear and logarithmic axis scales. Besides digitizing points off of data plots, this program can be used to digitize other types of scanned data (such as scaled drawings or orthographic photos).


%prep
%setup -q -n %{name}_Source
cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} lib/.

# remove the third party jars
find . -iname '*.jar' | xargs rm -rf

%build
# rebuild MRJAdapter
cd  lib
unzip MRJAdapter_1.0.8_Src.zip
cd MRJAdapter\ 1.0.8
#update target version
sed -i 's/target="1.1"/target="1.5"/' build.xml
sed -i 's/target="1.5"/target="1.5"\nsource="1.4"/' build.xml

%ant --execdebug library
cd ../..

#create barebonesbrowserlaunch
# taken from http://www.centerkey.com/java/browser/myapp/full-make.sh.command
cd lib
mkdir -p com/centerkey/utils
mv ../BareBonesBrowserLaunch.java com/centerkey/utils
javac -source 5 -target 5 com/centerkey/utils/*java
javadoc -d doc com/centerkey/utils/*.java
jar cvf bare-bones-browser-launch.jar com/centerkey/utils/*.* doc
mv bare-bones-browser-launch.jar bare-bones-browser-launch-3.1.jar
rm -r doc
rm -r com
cd ..

# remove mac and windows build instructions
sed -i '/<target name="\(run\|install\|package\|exe\)"/,/<\/target>/ d' build.xml
sed -i '/macos/d' build.xml
sed -i '/launch4j/d' build.xml

%ant jar

%install
# jars
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -m 0644 jars/%{name}.jar %{buildroot}%{_datadir}/%{name}/

# startscript
install -d -m 0755 %{buildroot}%{_bindir}
cat > %{buildroot}%{_bindir}/%{name} << EOF
#!/bin/sh
exec java -Xmx128m -jar %{_datadir}/%{name}/%{name}.jar
EOF
chmod 0755 %{buildroot}%{_bindir}/%{name}

install -Dm 644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 644 Resources/images/%{name}Icon64x64.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

install -Dm0644 %{S:4} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%files
%defattr(-, root, root)
%doc LesserGPL_license.txt README.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Sat Aug  6 2016 badshah400@gmail.com
- Fix incorrect name in appdata file.
* Fri Jul 29 2016 badshah400@gmail.com
- Add appdata file as source and install it to the appdata dir.
* Mon Dec 21 2015 badshah400@gmail.com
- Update to version 2.6.8:
  + Fixed a bug that could cause an exception to be thrown at
    program startup under certain circumstances.
- Changes from version 2.6.7:
  + Fixed a long-standing problem with the items in the "Windows"
    menu getting out of synch with the open windows.
  + Minor improvements to the auto-digitizing feature.
  + Turned off logging used for debugging purposes.
* Mon Mar  2 2015 sfalken@opensuse.org
- Removed BuildRequire update-desktop-files and
  %%suse_update_desktop_file, not needed, as desktop file is
  provided.  Updated categories in .desktop file to clear
  brp-check-suse failure in Factory
* Sat Jun 28 2014 badshah400@gmail.com
- Update to version 2.6.6:
  + Fixed a threading issue that could cause the program to
    randomly freeze up on some systems
- Changes from version 2.6.5:
  + Introduced a French localization of the program
  + Improved internationalization support throughout the program
  + Fixed a bug that would cause the program to calculate the
    incorrect polygon area in many cases
  + Now requires Java 1.6 or later.
* Fri Mar 14 2014 badshah400@gmail.com
- Update to version 2.6.4:
  + Another attempt at fixing an illusive bug where the open
    dialog will sometimes fail on Linux systems.
* Sun Jul  7 2013 dmitry_r@opensuse.org
- Update to version 2.6.3
  * The output CSV file format has been changed back to the
    pre 2.6.0 format and now (once again) always writes out numbers
    in the US Locale (preventing commas from being output that
    indicate the ones place in some locales).
  * The values written out to the CSV file and displayed in
    the window of digitized values now use a format that shows more
    precision for both very large and very small numbers.
  * Fixed a bug that prevented exporting a calibration for more
    than one plot per session.
  * Fixed a bug that prevented editing of values in the table
    of digitized values under some circumstances.
  * Fixed display and editing bugs related to the use of
    logarithmic axis scales.
* Fri May 17 2013 jengelh@inai.de
- Do not do more than unpack in %%prep stage (it can easily make
  `quilt setup` fail due to non-existing BuildRequires).
  Remove redundant %%clean section.
* Wed Jan  2 2013 cfarrell@suse.com
- license update: LGPL-2.1 and GPL-2.0
  Package also contains GPL components. See e.g.
  /PlotDigitizer_Source/src/jahuwaldt/image/BMPWriter.java
* Fri Dec 28 2012 dmitry_r@opensuse.org
- Update to version 2.6.2
  * Added a zoom capability allowing the user to zoom in and out
    on an image being digitized.
  * Added an optional grid display to the scaled axes.
  * Calibration data can now be exported to a file so you do not
    have to recalibrate to return to digitizing an image later.
  * Previously digitized points saved to a CSV file can now be
    re-imported to a calibrated image.
  * Added ability to change the plot symbol, size and color
    as a preference.
  * Improved robustness for running autotrace.
  * Corrected a bug with the number of fraction digits
    written to the CSV output file.
* Sat Aug 18 2012 dmitry_r@opensuse.org
- Spec file cleanups
- Add desktop file
* Sun Dec  4 2011 arun@gmx.de
- Initial package, version 2.5.1
